# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class LdapConfigPart(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ldap_access_id': 'str',
        'ldap_anonymous_search': 'bool',
        'ldap_bind_dn': 'str',
        'ldap_bind_password': 'str',
        'ldap_cert': 'str',
        'ldap_enable': 'bool',
        'ldap_group_attr': 'str',
        'ldap_group_dn': 'str',
        'ldap_group_filter': 'str',
        'ldap_private_key': 'str',
        'ldap_token_expiration': 'str',
        'ldap_url': 'str',
        'ldap_user_attr': 'str',
        'ldap_user_dn': 'str'
    }

    attribute_map = {
        'ldap_access_id': 'ldap_access_id',
        'ldap_anonymous_search': 'ldap_anonymous_search',
        'ldap_bind_dn': 'ldap_bind_dn',
        'ldap_bind_password': 'ldap_bind_password',
        'ldap_cert': 'ldap_cert',
        'ldap_enable': 'ldap_enable',
        'ldap_group_attr': 'ldap_group_attr',
        'ldap_group_dn': 'ldap_group_dn',
        'ldap_group_filter': 'ldap_group_filter',
        'ldap_private_key': 'ldap_private_key',
        'ldap_token_expiration': 'ldap_token_expiration',
        'ldap_url': 'ldap_url',
        'ldap_user_attr': 'ldap_user_attr',
        'ldap_user_dn': 'ldap_user_dn'
    }

    def __init__(self, ldap_access_id=None, ldap_anonymous_search=None, ldap_bind_dn=None, ldap_bind_password=None, ldap_cert=None, ldap_enable=None, ldap_group_attr=None, ldap_group_dn=None, ldap_group_filter=None, ldap_private_key=None, ldap_token_expiration=None, ldap_url=None, ldap_user_attr=None, ldap_user_dn=None, local_vars_configuration=None):  # noqa: E501
        """LdapConfigPart - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ldap_access_id = None
        self._ldap_anonymous_search = None
        self._ldap_bind_dn = None
        self._ldap_bind_password = None
        self._ldap_cert = None
        self._ldap_enable = None
        self._ldap_group_attr = None
        self._ldap_group_dn = None
        self._ldap_group_filter = None
        self._ldap_private_key = None
        self._ldap_token_expiration = None
        self._ldap_url = None
        self._ldap_user_attr = None
        self._ldap_user_dn = None
        self.discriminator = None

        if ldap_access_id is not None:
            self.ldap_access_id = ldap_access_id
        if ldap_anonymous_search is not None:
            self.ldap_anonymous_search = ldap_anonymous_search
        if ldap_bind_dn is not None:
            self.ldap_bind_dn = ldap_bind_dn
        if ldap_bind_password is not None:
            self.ldap_bind_password = ldap_bind_password
        if ldap_cert is not None:
            self.ldap_cert = ldap_cert
        if ldap_enable is not None:
            self.ldap_enable = ldap_enable
        if ldap_group_attr is not None:
            self.ldap_group_attr = ldap_group_attr
        if ldap_group_dn is not None:
            self.ldap_group_dn = ldap_group_dn
        if ldap_group_filter is not None:
            self.ldap_group_filter = ldap_group_filter
        if ldap_private_key is not None:
            self.ldap_private_key = ldap_private_key
        if ldap_token_expiration is not None:
            self.ldap_token_expiration = ldap_token_expiration
        if ldap_url is not None:
            self.ldap_url = ldap_url
        if ldap_user_attr is not None:
            self.ldap_user_attr = ldap_user_attr
        if ldap_user_dn is not None:
            self.ldap_user_dn = ldap_user_dn

    @property
    def ldap_access_id(self):
        """Gets the ldap_access_id of this LdapConfigPart.  # noqa: E501


        :return: The ldap_access_id of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_access_id

    @ldap_access_id.setter
    def ldap_access_id(self, ldap_access_id):
        """Sets the ldap_access_id of this LdapConfigPart.


        :param ldap_access_id: The ldap_access_id of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_access_id = ldap_access_id

    @property
    def ldap_anonymous_search(self):
        """Gets the ldap_anonymous_search of this LdapConfigPart.  # noqa: E501


        :return: The ldap_anonymous_search of this LdapConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_anonymous_search

    @ldap_anonymous_search.setter
    def ldap_anonymous_search(self, ldap_anonymous_search):
        """Sets the ldap_anonymous_search of this LdapConfigPart.


        :param ldap_anonymous_search: The ldap_anonymous_search of this LdapConfigPart.  # noqa: E501
        :type: bool
        """

        self._ldap_anonymous_search = ldap_anonymous_search

    @property
    def ldap_bind_dn(self):
        """Gets the ldap_bind_dn of this LdapConfigPart.  # noqa: E501


        :return: The ldap_bind_dn of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_bind_dn

    @ldap_bind_dn.setter
    def ldap_bind_dn(self, ldap_bind_dn):
        """Sets the ldap_bind_dn of this LdapConfigPart.


        :param ldap_bind_dn: The ldap_bind_dn of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_bind_dn = ldap_bind_dn

    @property
    def ldap_bind_password(self):
        """Gets the ldap_bind_password of this LdapConfigPart.  # noqa: E501


        :return: The ldap_bind_password of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_bind_password

    @ldap_bind_password.setter
    def ldap_bind_password(self, ldap_bind_password):
        """Sets the ldap_bind_password of this LdapConfigPart.


        :param ldap_bind_password: The ldap_bind_password of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_bind_password = ldap_bind_password

    @property
    def ldap_cert(self):
        """Gets the ldap_cert of this LdapConfigPart.  # noqa: E501


        :return: The ldap_cert of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_cert

    @ldap_cert.setter
    def ldap_cert(self, ldap_cert):
        """Sets the ldap_cert of this LdapConfigPart.


        :param ldap_cert: The ldap_cert of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_cert = ldap_cert

    @property
    def ldap_enable(self):
        """Gets the ldap_enable of this LdapConfigPart.  # noqa: E501


        :return: The ldap_enable of this LdapConfigPart.  # noqa: E501
        :rtype: bool
        """
        return self._ldap_enable

    @ldap_enable.setter
    def ldap_enable(self, ldap_enable):
        """Sets the ldap_enable of this LdapConfigPart.


        :param ldap_enable: The ldap_enable of this LdapConfigPart.  # noqa: E501
        :type: bool
        """

        self._ldap_enable = ldap_enable

    @property
    def ldap_group_attr(self):
        """Gets the ldap_group_attr of this LdapConfigPart.  # noqa: E501


        :return: The ldap_group_attr of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_group_attr

    @ldap_group_attr.setter
    def ldap_group_attr(self, ldap_group_attr):
        """Sets the ldap_group_attr of this LdapConfigPart.


        :param ldap_group_attr: The ldap_group_attr of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_group_attr = ldap_group_attr

    @property
    def ldap_group_dn(self):
        """Gets the ldap_group_dn of this LdapConfigPart.  # noqa: E501


        :return: The ldap_group_dn of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_group_dn

    @ldap_group_dn.setter
    def ldap_group_dn(self, ldap_group_dn):
        """Sets the ldap_group_dn of this LdapConfigPart.


        :param ldap_group_dn: The ldap_group_dn of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_group_dn = ldap_group_dn

    @property
    def ldap_group_filter(self):
        """Gets the ldap_group_filter of this LdapConfigPart.  # noqa: E501


        :return: The ldap_group_filter of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_group_filter

    @ldap_group_filter.setter
    def ldap_group_filter(self, ldap_group_filter):
        """Sets the ldap_group_filter of this LdapConfigPart.


        :param ldap_group_filter: The ldap_group_filter of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_group_filter = ldap_group_filter

    @property
    def ldap_private_key(self):
        """Gets the ldap_private_key of this LdapConfigPart.  # noqa: E501


        :return: The ldap_private_key of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_private_key

    @ldap_private_key.setter
    def ldap_private_key(self, ldap_private_key):
        """Sets the ldap_private_key of this LdapConfigPart.


        :param ldap_private_key: The ldap_private_key of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_private_key = ldap_private_key

    @property
    def ldap_token_expiration(self):
        """Gets the ldap_token_expiration of this LdapConfigPart.  # noqa: E501


        :return: The ldap_token_expiration of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_token_expiration

    @ldap_token_expiration.setter
    def ldap_token_expiration(self, ldap_token_expiration):
        """Sets the ldap_token_expiration of this LdapConfigPart.


        :param ldap_token_expiration: The ldap_token_expiration of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_token_expiration = ldap_token_expiration

    @property
    def ldap_url(self):
        """Gets the ldap_url of this LdapConfigPart.  # noqa: E501


        :return: The ldap_url of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_url

    @ldap_url.setter
    def ldap_url(self, ldap_url):
        """Sets the ldap_url of this LdapConfigPart.


        :param ldap_url: The ldap_url of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_url = ldap_url

    @property
    def ldap_user_attr(self):
        """Gets the ldap_user_attr of this LdapConfigPart.  # noqa: E501


        :return: The ldap_user_attr of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_user_attr

    @ldap_user_attr.setter
    def ldap_user_attr(self, ldap_user_attr):
        """Sets the ldap_user_attr of this LdapConfigPart.


        :param ldap_user_attr: The ldap_user_attr of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_user_attr = ldap_user_attr

    @property
    def ldap_user_dn(self):
        """Gets the ldap_user_dn of this LdapConfigPart.  # noqa: E501


        :return: The ldap_user_dn of this LdapConfigPart.  # noqa: E501
        :rtype: str
        """
        return self._ldap_user_dn

    @ldap_user_dn.setter
    def ldap_user_dn(self, ldap_user_dn):
        """Sets the ldap_user_dn of this LdapConfigPart.


        :param ldap_user_dn: The ldap_user_dn of this LdapConfigPart.  # noqa: E501
        :type: str
        """

        self._ldap_user_dn = ldap_user_dn

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LdapConfigPart):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LdapConfigPart):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class AssocTargetItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'json': 'bool',
        'key_operations': 'list[str]',
        'keyring_name': 'str',
        'kms_algorithm': 'str',
        'location_id': 'str',
        'multi_region': 'str',
        'name': 'str',
        'project_id': 'str',
        'purpose': 'str',
        'regions': 'list[str]',
        'target_name': 'str',
        'tenant_secret_type': 'str',
        'token': 'str',
        'uid_token': 'str',
        'vault_name': 'str'
    }

    attribute_map = {
        'json': 'json',
        'key_operations': 'key-operations',
        'keyring_name': 'keyring-name',
        'kms_algorithm': 'kms-algorithm',
        'location_id': 'location-id',
        'multi_region': 'multi-region',
        'name': 'name',
        'project_id': 'project-id',
        'purpose': 'purpose',
        'regions': 'regions',
        'target_name': 'target-name',
        'tenant_secret_type': 'tenant-secret-type',
        'token': 'token',
        'uid_token': 'uid-token',
        'vault_name': 'vault-name'
    }

    def __init__(self, json=None, key_operations=None, keyring_name=None, kms_algorithm=None, location_id=None, multi_region='false', name=None, project_id=None, purpose=None, regions=None, target_name=None, tenant_secret_type=None, token=None, uid_token=None, vault_name=None, local_vars_configuration=None):  # noqa: E501
        """AssocTargetItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._json = None
        self._key_operations = None
        self._keyring_name = None
        self._kms_algorithm = None
        self._location_id = None
        self._multi_region = None
        self._name = None
        self._project_id = None
        self._purpose = None
        self._regions = None
        self._target_name = None
        self._tenant_secret_type = None
        self._token = None
        self._uid_token = None
        self._vault_name = None
        self.discriminator = None

        if json is not None:
            self.json = json
        if key_operations is not None:
            self.key_operations = key_operations
        if keyring_name is not None:
            self.keyring_name = keyring_name
        if kms_algorithm is not None:
            self.kms_algorithm = kms_algorithm
        if location_id is not None:
            self.location_id = location_id
        if multi_region is not None:
            self.multi_region = multi_region
        self.name = name
        if project_id is not None:
            self.project_id = project_id
        if purpose is not None:
            self.purpose = purpose
        if regions is not None:
            self.regions = regions
        self.target_name = target_name
        if tenant_secret_type is not None:
            self.tenant_secret_type = tenant_secret_type
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if vault_name is not None:
            self.vault_name = vault_name

    @property
    def json(self):
        """Gets the json of this AssocTargetItem.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this AssocTargetItem.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this AssocTargetItem.

        Set output format to JSON  # noqa: E501

        :param json: The json of this AssocTargetItem.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def key_operations(self):
        """Gets the key_operations of this AssocTargetItem.  # noqa: E501

        A list of allowed operations for the key (required for azure targets)  # noqa: E501

        :return: The key_operations of this AssocTargetItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._key_operations

    @key_operations.setter
    def key_operations(self, key_operations):
        """Sets the key_operations of this AssocTargetItem.

        A list of allowed operations for the key (required for azure targets)  # noqa: E501

        :param key_operations: The key_operations of this AssocTargetItem.  # noqa: E501
        :type: list[str]
        """

        self._key_operations = key_operations

    @property
    def keyring_name(self):
        """Gets the keyring_name of this AssocTargetItem.  # noqa: E501

        Keyring name of the GCP KMS (required for gcp targets)  # noqa: E501

        :return: The keyring_name of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._keyring_name

    @keyring_name.setter
    def keyring_name(self, keyring_name):
        """Sets the keyring_name of this AssocTargetItem.

        Keyring name of the GCP KMS (required for gcp targets)  # noqa: E501

        :param keyring_name: The keyring_name of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._keyring_name = keyring_name

    @property
    def kms_algorithm(self):
        """Gets the kms_algorithm of this AssocTargetItem.  # noqa: E501

        Algorithm of the key in GCP KMS (required for gcp targets)  # noqa: E501

        :return: The kms_algorithm of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._kms_algorithm

    @kms_algorithm.setter
    def kms_algorithm(self, kms_algorithm):
        """Sets the kms_algorithm of this AssocTargetItem.

        Algorithm of the key in GCP KMS (required for gcp targets)  # noqa: E501

        :param kms_algorithm: The kms_algorithm of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._kms_algorithm = kms_algorithm

    @property
    def location_id(self):
        """Gets the location_id of this AssocTargetItem.  # noqa: E501

        Location id of the GCP KMS (required for gcp targets)  # noqa: E501

        :return: The location_id of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this AssocTargetItem.

        Location id of the GCP KMS (required for gcp targets)  # noqa: E501

        :param location_id: The location_id of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def multi_region(self):
        """Gets the multi_region of this AssocTargetItem.  # noqa: E501

        Set to 'true' to create a multi region managed key (relevant for aws targets)  # noqa: E501

        :return: The multi_region of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._multi_region

    @multi_region.setter
    def multi_region(self, multi_region):
        """Sets the multi_region of this AssocTargetItem.

        Set to 'true' to create a multi region managed key (relevant for aws targets)  # noqa: E501

        :param multi_region: The multi_region of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._multi_region = multi_region

    @property
    def name(self):
        """Gets the name of this AssocTargetItem.  # noqa: E501

        The item to associate  # noqa: E501

        :return: The name of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AssocTargetItem.

        The item to associate  # noqa: E501

        :param name: The name of this AssocTargetItem.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def project_id(self):
        """Gets the project_id of this AssocTargetItem.  # noqa: E501

        Project id of the GCP KMS (required for gcp targets)  # noqa: E501

        :return: The project_id of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id):
        """Sets the project_id of this AssocTargetItem.

        Project id of the GCP KMS (required for gcp targets)  # noqa: E501

        :param project_id: The project_id of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def purpose(self):
        """Gets the purpose of this AssocTargetItem.  # noqa: E501

        Purpose of the key in GCP KMS (required for gcp targets)  # noqa: E501

        :return: The purpose of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """Sets the purpose of this AssocTargetItem.

        Purpose of the key in GCP KMS (required for gcp targets)  # noqa: E501

        :param purpose: The purpose of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._purpose = purpose

    @property
    def regions(self):
        """Gets the regions of this AssocTargetItem.  # noqa: E501

        The list of regions to create a copy of the key in (relevant for aws targets)  # noqa: E501

        :return: The regions of this AssocTargetItem.  # noqa: E501
        :rtype: list[str]
        """
        return self._regions

    @regions.setter
    def regions(self, regions):
        """Sets the regions of this AssocTargetItem.

        The list of regions to create a copy of the key in (relevant for aws targets)  # noqa: E501

        :param regions: The regions of this AssocTargetItem.  # noqa: E501
        :type: list[str]
        """

        self._regions = regions

    @property
    def target_name(self):
        """Gets the target_name of this AssocTargetItem.  # noqa: E501

        The target to associate  # noqa: E501

        :return: The target_name of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this AssocTargetItem.

        The target to associate  # noqa: E501

        :param target_name: The target_name of this AssocTargetItem.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target_name is None:  # noqa: E501
            raise ValueError("Invalid value for `target_name`, must not be `None`")  # noqa: E501

        self._target_name = target_name

    @property
    def tenant_secret_type(self):
        """Gets the tenant_secret_type of this AssocTargetItem.  # noqa: E501

        The tenant secret type [Data/SearchIndex/Analytics] (required for salesforce targets)  # noqa: E501

        :return: The tenant_secret_type of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._tenant_secret_type

    @tenant_secret_type.setter
    def tenant_secret_type(self, tenant_secret_type):
        """Sets the tenant_secret_type of this AssocTargetItem.

        The tenant secret type [Data/SearchIndex/Analytics] (required for salesforce targets)  # noqa: E501

        :param tenant_secret_type: The tenant_secret_type of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._tenant_secret_type = tenant_secret_type

    @property
    def token(self):
        """Gets the token of this AssocTargetItem.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this AssocTargetItem.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this AssocTargetItem.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this AssocTargetItem.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def vault_name(self):
        """Gets the vault_name of this AssocTargetItem.  # noqa: E501

        Name of the vault used (required for azure targets)  # noqa: E501

        :return: The vault_name of this AssocTargetItem.  # noqa: E501
        :rtype: str
        """
        return self._vault_name

    @vault_name.setter
    def vault_name(self, vault_name):
        """Sets the vault_name of this AssocTargetItem.

        Name of the vault used (required for azure targets)  # noqa: E501

        :param vault_name: The vault_name of this AssocTargetItem.  # noqa: E501
        :type: str
        """

        self._vault_name = vault_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssocTargetItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssocTargetItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.config_change import ConfigChange  # noqa: E501
from akeyless.rest import ApiException

class TestConfigChange(unittest.TestCase):
    """ConfigChange unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ConfigChange
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.config_change.ConfigChange()  # noqa: E501
        if include_optional :
            return ConfigChange(
                config_hash = akeyless.models.config_hash.ConfigHash(
                    admins = '0', 
                    cache = '0', 
                    customer_fragements = '0', 
                    general = '0', 
                    k8s_auths = '0', 
                    kmip = '0', 
                    ldap = '0', 
                    leadership = '0', 
                    log_forwarding = '0', 
                    migrations = '0', 
                    producers = akeyless.models.producers.producers(), 
                    rotators = akeyless.models.rotators.rotators(), 
                    saml = '0', 
                    universal_identity = '0', ), 
                last_change = akeyless.models.last_config_change.LastConfigChange(
                    last_k8s_auths_change = akeyless.models.k8_s_auths_config_last_change.K8SAuthsConfigLastChange(
                        changed_k8s_auths_ids = [
                            '0'
                            ], 
                        created_k8s_auths_ids = [
                            '0'
                            ], 
                        deleted_k8s_auths_ids = [
                            '0'
                            ], ), 
                    last_migrations_change = akeyless.models.migrations_config_last_change.MigrationsConfigLastChange(
                        changed_migrations = [
                            '0'
                            ], 
                        created_migrations = [
                            '0'
                            ], 
                        deleted_migrations = [
                            '0'
                            ], ), ), 
                last_status = akeyless.models.last_status_info.LastStatusInfo(
                    migrations_status = akeyless.models.migration_status.MigrationStatus(
                        last_messages = {
                            'key' : '0'
                            }, 
                        last_statuses = {
                            'key' : '0'
                            }, ), 
                    producers_errors = akeyless.models.producers_errors.producers_errors(), ), 
                required_activity = akeyless.models.required_activity.RequiredActivity(
                    migrations_required_activity = {
                        'key' : True
                        }, ), 
                update_stamp = 56
            )
        else :
            return ConfigChange(
        )

    def testConfigChange(self):
        """Test ConfigChange"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ConfigHash(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'admins': 'str',
        'cache': 'str',
        'customer_fragements': 'str',
        'general': 'str',
        'k8s_auths': 'str',
        'kmip': 'str',
        'ldap': 'str',
        'leadership': 'str',
        'log_forwarding': 'str',
        'm_queue': 'str',
        'migration_status': 'str',
        'migrations': 'str',
        'producers': 'object',
        'producers_status': 'str',
        'rotators': 'object',
        'saml': 'str',
        'universal_identity': 'str'
    }

    attribute_map = {
        'admins': 'admins',
        'cache': 'cache',
        'customer_fragements': 'customer_fragements',
        'general': 'general',
        'k8s_auths': 'k8s_auths',
        'kmip': 'kmip',
        'ldap': 'ldap',
        'leadership': 'leadership',
        'log_forwarding': 'log_forwarding',
        'm_queue': 'm_queue',
        'migration_status': 'migration_status',
        'migrations': 'migrations',
        'producers': 'producers',
        'producers_status': 'producers_status',
        'rotators': 'rotators',
        'saml': 'saml',
        'universal_identity': 'universal_identity'
    }

    def __init__(self, admins=None, cache=None, customer_fragements=None, general=None, k8s_auths=None, kmip=None, ldap=None, leadership=None, log_forwarding=None, m_queue=None, migration_status=None, migrations=None, producers=None, producers_status=None, rotators=None, saml=None, universal_identity=None, local_vars_configuration=None):  # noqa: E501
        """ConfigHash - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._admins = None
        self._cache = None
        self._customer_fragements = None
        self._general = None
        self._k8s_auths = None
        self._kmip = None
        self._ldap = None
        self._leadership = None
        self._log_forwarding = None
        self._m_queue = None
        self._migration_status = None
        self._migrations = None
        self._producers = None
        self._producers_status = None
        self._rotators = None
        self._saml = None
        self._universal_identity = None
        self.discriminator = None

        if admins is not None:
            self.admins = admins
        if cache is not None:
            self.cache = cache
        if customer_fragements is not None:
            self.customer_fragements = customer_fragements
        if general is not None:
            self.general = general
        if k8s_auths is not None:
            self.k8s_auths = k8s_auths
        if kmip is not None:
            self.kmip = kmip
        if ldap is not None:
            self.ldap = ldap
        if leadership is not None:
            self.leadership = leadership
        if log_forwarding is not None:
            self.log_forwarding = log_forwarding
        if m_queue is not None:
            self.m_queue = m_queue
        if migration_status is not None:
            self.migration_status = migration_status
        if migrations is not None:
            self.migrations = migrations
        if producers is not None:
            self.producers = producers
        if producers_status is not None:
            self.producers_status = producers_status
        if rotators is not None:
            self.rotators = rotators
        if saml is not None:
            self.saml = saml
        if universal_identity is not None:
            self.universal_identity = universal_identity

    @property
    def admins(self):
        """Gets the admins of this ConfigHash.  # noqa: E501


        :return: The admins of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._admins

    @admins.setter
    def admins(self, admins):
        """Sets the admins of this ConfigHash.


        :param admins: The admins of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._admins = admins

    @property
    def cache(self):
        """Gets the cache of this ConfigHash.  # noqa: E501


        :return: The cache of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._cache

    @cache.setter
    def cache(self, cache):
        """Sets the cache of this ConfigHash.


        :param cache: The cache of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._cache = cache

    @property
    def customer_fragements(self):
        """Gets the customer_fragements of this ConfigHash.  # noqa: E501


        :return: The customer_fragements of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._customer_fragements

    @customer_fragements.setter
    def customer_fragements(self, customer_fragements):
        """Sets the customer_fragements of this ConfigHash.


        :param customer_fragements: The customer_fragements of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._customer_fragements = customer_fragements

    @property
    def general(self):
        """Gets the general of this ConfigHash.  # noqa: E501


        :return: The general of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._general

    @general.setter
    def general(self, general):
        """Sets the general of this ConfigHash.


        :param general: The general of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._general = general

    @property
    def k8s_auths(self):
        """Gets the k8s_auths of this ConfigHash.  # noqa: E501


        :return: The k8s_auths of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._k8s_auths

    @k8s_auths.setter
    def k8s_auths(self, k8s_auths):
        """Sets the k8s_auths of this ConfigHash.


        :param k8s_auths: The k8s_auths of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._k8s_auths = k8s_auths

    @property
    def kmip(self):
        """Gets the kmip of this ConfigHash.  # noqa: E501


        :return: The kmip of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._kmip

    @kmip.setter
    def kmip(self, kmip):
        """Sets the kmip of this ConfigHash.


        :param kmip: The kmip of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._kmip = kmip

    @property
    def ldap(self):
        """Gets the ldap of this ConfigHash.  # noqa: E501


        :return: The ldap of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._ldap

    @ldap.setter
    def ldap(self, ldap):
        """Sets the ldap of this ConfigHash.


        :param ldap: The ldap of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._ldap = ldap

    @property
    def leadership(self):
        """Gets the leadership of this ConfigHash.  # noqa: E501


        :return: The leadership of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._leadership

    @leadership.setter
    def leadership(self, leadership):
        """Sets the leadership of this ConfigHash.


        :param leadership: The leadership of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._leadership = leadership

    @property
    def log_forwarding(self):
        """Gets the log_forwarding of this ConfigHash.  # noqa: E501


        :return: The log_forwarding of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._log_forwarding

    @log_forwarding.setter
    def log_forwarding(self, log_forwarding):
        """Sets the log_forwarding of this ConfigHash.


        :param log_forwarding: The log_forwarding of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._log_forwarding = log_forwarding

    @property
    def m_queue(self):
        """Gets the m_queue of this ConfigHash.  # noqa: E501


        :return: The m_queue of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._m_queue

    @m_queue.setter
    def m_queue(self, m_queue):
        """Sets the m_queue of this ConfigHash.


        :param m_queue: The m_queue of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._m_queue = m_queue

    @property
    def migration_status(self):
        """Gets the migration_status of this ConfigHash.  # noqa: E501


        :return: The migration_status of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._migration_status

    @migration_status.setter
    def migration_status(self, migration_status):
        """Sets the migration_status of this ConfigHash.


        :param migration_status: The migration_status of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._migration_status = migration_status

    @property
    def migrations(self):
        """Gets the migrations of this ConfigHash.  # noqa: E501


        :return: The migrations of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._migrations

    @migrations.setter
    def migrations(self, migrations):
        """Sets the migrations of this ConfigHash.


        :param migrations: The migrations of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._migrations = migrations

    @property
    def producers(self):
        """Gets the producers of this ConfigHash.  # noqa: E501


        :return: The producers of this ConfigHash.  # noqa: E501
        :rtype: object
        """
        return self._producers

    @producers.setter
    def producers(self, producers):
        """Sets the producers of this ConfigHash.


        :param producers: The producers of this ConfigHash.  # noqa: E501
        :type: object
        """

        self._producers = producers

    @property
    def producers_status(self):
        """Gets the producers_status of this ConfigHash.  # noqa: E501


        :return: The producers_status of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._producers_status

    @producers_status.setter
    def producers_status(self, producers_status):
        """Sets the producers_status of this ConfigHash.


        :param producers_status: The producers_status of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._producers_status = producers_status

    @property
    def rotators(self):
        """Gets the rotators of this ConfigHash.  # noqa: E501


        :return: The rotators of this ConfigHash.  # noqa: E501
        :rtype: object
        """
        return self._rotators

    @rotators.setter
    def rotators(self, rotators):
        """Sets the rotators of this ConfigHash.


        :param rotators: The rotators of this ConfigHash.  # noqa: E501
        :type: object
        """

        self._rotators = rotators

    @property
    def saml(self):
        """Gets the saml of this ConfigHash.  # noqa: E501


        :return: The saml of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._saml

    @saml.setter
    def saml(self, saml):
        """Sets the saml of this ConfigHash.


        :param saml: The saml of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._saml = saml

    @property
    def universal_identity(self):
        """Gets the universal_identity of this ConfigHash.  # noqa: E501


        :return: The universal_identity of this ConfigHash.  # noqa: E501
        :rtype: str
        """
        return self._universal_identity

    @universal_identity.setter
    def universal_identity(self, universal_identity):
        """Sets the universal_identity of this ConfigHash.


        :param universal_identity: The universal_identity of this ConfigHash.  # noqa: E501
        :type: str
        """

        self._universal_identity = universal_identity

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigHash):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConfigHash):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class GatewayUpdateProducerRdp(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allow_user_extend_session': 'int',
        'delete_protection': 'str',
        'fixed_user_only': 'str',
        'json': 'bool',
        'name': 'str',
        'new_name': 'str',
        'producer_encryption_key_name': 'str',
        'rdp_admin_name': 'str',
        'rdp_admin_pwd': 'str',
        'rdp_host_name': 'str',
        'rdp_host_port': 'str',
        'rdp_user_groups': 'str',
        'secure_access_allow_external_user': 'bool',
        'secure_access_enable': 'str',
        'secure_access_host': 'list[str]',
        'secure_access_rdp_domain': 'str',
        'secure_access_rdp_user': 'str',
        'tags': 'list[str]',
        'target_name': 'str',
        'token': 'str',
        'uid_token': 'str',
        'user_ttl': 'str',
        'warn_user_before_expiration': 'int'
    }

    attribute_map = {
        'allow_user_extend_session': 'allow-user-extend-session',
        'delete_protection': 'delete_protection',
        'fixed_user_only': 'fixed-user-only',
        'json': 'json',
        'name': 'name',
        'new_name': 'new-name',
        'producer_encryption_key_name': 'producer-encryption-key-name',
        'rdp_admin_name': 'rdp-admin-name',
        'rdp_admin_pwd': 'rdp-admin-pwd',
        'rdp_host_name': 'rdp-host-name',
        'rdp_host_port': 'rdp-host-port',
        'rdp_user_groups': 'rdp-user-groups',
        'secure_access_allow_external_user': 'secure-access-allow-external-user',
        'secure_access_enable': 'secure-access-enable',
        'secure_access_host': 'secure-access-host',
        'secure_access_rdp_domain': 'secure-access-rdp-domain',
        'secure_access_rdp_user': 'secure-access-rdp-user',
        'tags': 'tags',
        'target_name': 'target-name',
        'token': 'token',
        'uid_token': 'uid-token',
        'user_ttl': 'user-ttl',
        'warn_user_before_expiration': 'warn-user-before-expiration'
    }

    def __init__(self, allow_user_extend_session=None, delete_protection=None, fixed_user_only='false', json=None, name=None, new_name=None, producer_encryption_key_name=None, rdp_admin_name=None, rdp_admin_pwd=None, rdp_host_name=None, rdp_host_port='22', rdp_user_groups=None, secure_access_allow_external_user=None, secure_access_enable=None, secure_access_host=None, secure_access_rdp_domain=None, secure_access_rdp_user=None, tags=None, target_name=None, token=None, uid_token=None, user_ttl='60m', warn_user_before_expiration=None, local_vars_configuration=None):  # noqa: E501
        """GatewayUpdateProducerRdp - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allow_user_extend_session = None
        self._delete_protection = None
        self._fixed_user_only = None
        self._json = None
        self._name = None
        self._new_name = None
        self._producer_encryption_key_name = None
        self._rdp_admin_name = None
        self._rdp_admin_pwd = None
        self._rdp_host_name = None
        self._rdp_host_port = None
        self._rdp_user_groups = None
        self._secure_access_allow_external_user = None
        self._secure_access_enable = None
        self._secure_access_host = None
        self._secure_access_rdp_domain = None
        self._secure_access_rdp_user = None
        self._tags = None
        self._target_name = None
        self._token = None
        self._uid_token = None
        self._user_ttl = None
        self._warn_user_before_expiration = None
        self.discriminator = None

        if allow_user_extend_session is not None:
            self.allow_user_extend_session = allow_user_extend_session
        if delete_protection is not None:
            self.delete_protection = delete_protection
        if fixed_user_only is not None:
            self.fixed_user_only = fixed_user_only
        if json is not None:
            self.json = json
        self.name = name
        if new_name is not None:
            self.new_name = new_name
        if producer_encryption_key_name is not None:
            self.producer_encryption_key_name = producer_encryption_key_name
        if rdp_admin_name is not None:
            self.rdp_admin_name = rdp_admin_name
        if rdp_admin_pwd is not None:
            self.rdp_admin_pwd = rdp_admin_pwd
        if rdp_host_name is not None:
            self.rdp_host_name = rdp_host_name
        if rdp_host_port is not None:
            self.rdp_host_port = rdp_host_port
        if rdp_user_groups is not None:
            self.rdp_user_groups = rdp_user_groups
        if secure_access_allow_external_user is not None:
            self.secure_access_allow_external_user = secure_access_allow_external_user
        if secure_access_enable is not None:
            self.secure_access_enable = secure_access_enable
        if secure_access_host is not None:
            self.secure_access_host = secure_access_host
        if secure_access_rdp_domain is not None:
            self.secure_access_rdp_domain = secure_access_rdp_domain
        if secure_access_rdp_user is not None:
            self.secure_access_rdp_user = secure_access_rdp_user
        if tags is not None:
            self.tags = tags
        if target_name is not None:
            self.target_name = target_name
        if token is not None:
            self.token = token
        if uid_token is not None:
            self.uid_token = uid_token
        if user_ttl is not None:
            self.user_ttl = user_ttl
        if warn_user_before_expiration is not None:
            self.warn_user_before_expiration = warn_user_before_expiration

    @property
    def allow_user_extend_session(self):
        """Gets the allow_user_extend_session of this GatewayUpdateProducerRdp.  # noqa: E501

        AllowUserExtendSession  # noqa: E501

        :return: The allow_user_extend_session of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: int
        """
        return self._allow_user_extend_session

    @allow_user_extend_session.setter
    def allow_user_extend_session(self, allow_user_extend_session):
        """Sets the allow_user_extend_session of this GatewayUpdateProducerRdp.

        AllowUserExtendSession  # noqa: E501

        :param allow_user_extend_session: The allow_user_extend_session of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: int
        """

        self._allow_user_extend_session = allow_user_extend_session

    @property
    def delete_protection(self):
        """Gets the delete_protection of this GatewayUpdateProducerRdp.  # noqa: E501

        Protection from accidental deletion of this item  # noqa: E501

        :return: The delete_protection of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._delete_protection

    @delete_protection.setter
    def delete_protection(self, delete_protection):
        """Sets the delete_protection of this GatewayUpdateProducerRdp.

        Protection from accidental deletion of this item  # noqa: E501

        :param delete_protection: The delete_protection of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._delete_protection = delete_protection

    @property
    def fixed_user_only(self):
        """Gets the fixed_user_only of this GatewayUpdateProducerRdp.  # noqa: E501

        Fixed user  # noqa: E501

        :return: The fixed_user_only of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._fixed_user_only

    @fixed_user_only.setter
    def fixed_user_only(self, fixed_user_only):
        """Sets the fixed_user_only of this GatewayUpdateProducerRdp.

        Fixed user  # noqa: E501

        :param fixed_user_only: The fixed_user_only of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._fixed_user_only = fixed_user_only

    @property
    def json(self):
        """Gets the json of this GatewayUpdateProducerRdp.  # noqa: E501

        Set output format to JSON  # noqa: E501

        :return: The json of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: bool
        """
        return self._json

    @json.setter
    def json(self, json):
        """Sets the json of this GatewayUpdateProducerRdp.

        Set output format to JSON  # noqa: E501

        :param json: The json of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: bool
        """

        self._json = json

    @property
    def name(self):
        """Gets the name of this GatewayUpdateProducerRdp.  # noqa: E501

        Producer name  # noqa: E501

        :return: The name of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this GatewayUpdateProducerRdp.

        Producer name  # noqa: E501

        :param name: The name of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def new_name(self):
        """Gets the new_name of this GatewayUpdateProducerRdp.  # noqa: E501

        Producer name  # noqa: E501

        :return: The new_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._new_name

    @new_name.setter
    def new_name(self, new_name):
        """Sets the new_name of this GatewayUpdateProducerRdp.

        Producer name  # noqa: E501

        :param new_name: The new_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._new_name = new_name

    @property
    def producer_encryption_key_name(self):
        """Gets the producer_encryption_key_name of this GatewayUpdateProducerRdp.  # noqa: E501

        Dynamic producer encryption key  # noqa: E501

        :return: The producer_encryption_key_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._producer_encryption_key_name

    @producer_encryption_key_name.setter
    def producer_encryption_key_name(self, producer_encryption_key_name):
        """Sets the producer_encryption_key_name of this GatewayUpdateProducerRdp.

        Dynamic producer encryption key  # noqa: E501

        :param producer_encryption_key_name: The producer_encryption_key_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._producer_encryption_key_name = producer_encryption_key_name

    @property
    def rdp_admin_name(self):
        """Gets the rdp_admin_name of this GatewayUpdateProducerRdp.  # noqa: E501

        RDP Admin Name  # noqa: E501

        :return: The rdp_admin_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._rdp_admin_name

    @rdp_admin_name.setter
    def rdp_admin_name(self, rdp_admin_name):
        """Sets the rdp_admin_name of this GatewayUpdateProducerRdp.

        RDP Admin Name  # noqa: E501

        :param rdp_admin_name: The rdp_admin_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._rdp_admin_name = rdp_admin_name

    @property
    def rdp_admin_pwd(self):
        """Gets the rdp_admin_pwd of this GatewayUpdateProducerRdp.  # noqa: E501

        RDP Admin password  # noqa: E501

        :return: The rdp_admin_pwd of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._rdp_admin_pwd

    @rdp_admin_pwd.setter
    def rdp_admin_pwd(self, rdp_admin_pwd):
        """Sets the rdp_admin_pwd of this GatewayUpdateProducerRdp.

        RDP Admin password  # noqa: E501

        :param rdp_admin_pwd: The rdp_admin_pwd of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._rdp_admin_pwd = rdp_admin_pwd

    @property
    def rdp_host_name(self):
        """Gets the rdp_host_name of this GatewayUpdateProducerRdp.  # noqa: E501

        Hostname  # noqa: E501

        :return: The rdp_host_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._rdp_host_name

    @rdp_host_name.setter
    def rdp_host_name(self, rdp_host_name):
        """Sets the rdp_host_name of this GatewayUpdateProducerRdp.

        Hostname  # noqa: E501

        :param rdp_host_name: The rdp_host_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._rdp_host_name = rdp_host_name

    @property
    def rdp_host_port(self):
        """Gets the rdp_host_port of this GatewayUpdateProducerRdp.  # noqa: E501

        Port  # noqa: E501

        :return: The rdp_host_port of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._rdp_host_port

    @rdp_host_port.setter
    def rdp_host_port(self, rdp_host_port):
        """Sets the rdp_host_port of this GatewayUpdateProducerRdp.

        Port  # noqa: E501

        :param rdp_host_port: The rdp_host_port of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._rdp_host_port = rdp_host_port

    @property
    def rdp_user_groups(self):
        """Gets the rdp_user_groups of this GatewayUpdateProducerRdp.  # noqa: E501

        Groups  # noqa: E501

        :return: The rdp_user_groups of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._rdp_user_groups

    @rdp_user_groups.setter
    def rdp_user_groups(self, rdp_user_groups):
        """Sets the rdp_user_groups of this GatewayUpdateProducerRdp.

        Groups  # noqa: E501

        :param rdp_user_groups: The rdp_user_groups of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._rdp_user_groups = rdp_user_groups

    @property
    def secure_access_allow_external_user(self):
        """Gets the secure_access_allow_external_user of this GatewayUpdateProducerRdp.  # noqa: E501


        :return: The secure_access_allow_external_user of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: bool
        """
        return self._secure_access_allow_external_user

    @secure_access_allow_external_user.setter
    def secure_access_allow_external_user(self, secure_access_allow_external_user):
        """Sets the secure_access_allow_external_user of this GatewayUpdateProducerRdp.


        :param secure_access_allow_external_user: The secure_access_allow_external_user of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: bool
        """

        self._secure_access_allow_external_user = secure_access_allow_external_user

    @property
    def secure_access_enable(self):
        """Gets the secure_access_enable of this GatewayUpdateProducerRdp.  # noqa: E501


        :return: The secure_access_enable of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_enable

    @secure_access_enable.setter
    def secure_access_enable(self, secure_access_enable):
        """Sets the secure_access_enable of this GatewayUpdateProducerRdp.


        :param secure_access_enable: The secure_access_enable of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._secure_access_enable = secure_access_enable

    @property
    def secure_access_host(self):
        """Gets the secure_access_host of this GatewayUpdateProducerRdp.  # noqa: E501


        :return: The secure_access_host of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: list[str]
        """
        return self._secure_access_host

    @secure_access_host.setter
    def secure_access_host(self, secure_access_host):
        """Sets the secure_access_host of this GatewayUpdateProducerRdp.


        :param secure_access_host: The secure_access_host of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: list[str]
        """

        self._secure_access_host = secure_access_host

    @property
    def secure_access_rdp_domain(self):
        """Gets the secure_access_rdp_domain of this GatewayUpdateProducerRdp.  # noqa: E501


        :return: The secure_access_rdp_domain of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_rdp_domain

    @secure_access_rdp_domain.setter
    def secure_access_rdp_domain(self, secure_access_rdp_domain):
        """Sets the secure_access_rdp_domain of this GatewayUpdateProducerRdp.


        :param secure_access_rdp_domain: The secure_access_rdp_domain of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._secure_access_rdp_domain = secure_access_rdp_domain

    @property
    def secure_access_rdp_user(self):
        """Gets the secure_access_rdp_user of this GatewayUpdateProducerRdp.  # noqa: E501


        :return: The secure_access_rdp_user of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._secure_access_rdp_user

    @secure_access_rdp_user.setter
    def secure_access_rdp_user(self, secure_access_rdp_user):
        """Sets the secure_access_rdp_user of this GatewayUpdateProducerRdp.


        :param secure_access_rdp_user: The secure_access_rdp_user of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._secure_access_rdp_user = secure_access_rdp_user

    @property
    def tags(self):
        """Gets the tags of this GatewayUpdateProducerRdp.  # noqa: E501

        List of the tags attached to this secret  # noqa: E501

        :return: The tags of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this GatewayUpdateProducerRdp.

        List of the tags attached to this secret  # noqa: E501

        :param tags: The tags of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def target_name(self):
        """Gets the target_name of this GatewayUpdateProducerRdp.  # noqa: E501

        Target name  # noqa: E501

        :return: The target_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._target_name

    @target_name.setter
    def target_name(self, target_name):
        """Sets the target_name of this GatewayUpdateProducerRdp.

        Target name  # noqa: E501

        :param target_name: The target_name of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._target_name = target_name

    @property
    def token(self):
        """Gets the token of this GatewayUpdateProducerRdp.  # noqa: E501

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :return: The token of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._token

    @token.setter
    def token(self, token):
        """Sets the token of this GatewayUpdateProducerRdp.

        Authentication token (see `/auth` and `/configure`)  # noqa: E501

        :param token: The token of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._token = token

    @property
    def uid_token(self):
        """Gets the uid_token of this GatewayUpdateProducerRdp.  # noqa: E501

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :return: The uid_token of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._uid_token

    @uid_token.setter
    def uid_token(self, uid_token):
        """Sets the uid_token of this GatewayUpdateProducerRdp.

        The universal identity token, Required only for universal_identity authentication  # noqa: E501

        :param uid_token: The uid_token of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._uid_token = uid_token

    @property
    def user_ttl(self):
        """Gets the user_ttl of this GatewayUpdateProducerRdp.  # noqa: E501

        User TTL  # noqa: E501

        :return: The user_ttl of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: str
        """
        return self._user_ttl

    @user_ttl.setter
    def user_ttl(self, user_ttl):
        """Sets the user_ttl of this GatewayUpdateProducerRdp.

        User TTL  # noqa: E501

        :param user_ttl: The user_ttl of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: str
        """

        self._user_ttl = user_ttl

    @property
    def warn_user_before_expiration(self):
        """Gets the warn_user_before_expiration of this GatewayUpdateProducerRdp.  # noqa: E501

        WarnBeforeUserExpiration  # noqa: E501

        :return: The warn_user_before_expiration of this GatewayUpdateProducerRdp.  # noqa: E501
        :rtype: int
        """
        return self._warn_user_before_expiration

    @warn_user_before_expiration.setter
    def warn_user_before_expiration(self, warn_user_before_expiration):
        """Sets the warn_user_before_expiration of this GatewayUpdateProducerRdp.

        WarnBeforeUserExpiration  # noqa: E501

        :param warn_user_before_expiration: The warn_user_before_expiration of this GatewayUpdateProducerRdp.  # noqa: E501
        :type: int
        """

        self._warn_user_before_expiration = warn_user_before_expiration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GatewayUpdateProducerRdp):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GatewayUpdateProducerRdp):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import akeyless
from akeyless.models.active_directory_migration import ActiveDirectoryMigration  # noqa: E501
from akeyless.rest import ApiException

class TestActiveDirectoryMigration(unittest.TestCase):
    """ActiveDirectoryMigration unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ActiveDirectoryMigration
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = akeyless.models.active_directory_migration.ActiveDirectoryMigration()  # noqa: E501
        if include_optional :
            return ActiveDirectoryMigration(
                general = akeyless.models.migration_general.MigrationGeneral(
                    id = '0', 
                    name = '0', 
                    new_name = '0', 
                    prefix = '0', 
                    protection_key = '0', ), 
                payload = akeyless.models.active_directory_payload.ActiveDirectoryPayload(
                    active_directory_target_id = 56, 
                    auto_rotate = True, 
                    auto_rotate_interval_in_days = 56, 
                    auto_rotate_rotation_hour = 56, 
                    computer_base_dn = '0', 
                    discover_local_users = True, 
                    domain_name = '0', 
                    domain_server_targets_path_template = '0', 
                    domain_users_rotated_secrets_path_template = '0', 
                    enable_rdp_sra = True, 
                    local_users_ignore_list = {
                        'key' : True
                        }, 
                    local_users_rotated_secrets_path_template = '0', 
                    ssh_port = '0', 
                    user_base_dn = '0', 
                    user_groups = [
                        '0'
                        ], )
            )
        else :
            return ActiveDirectoryMigration(
        )

    def testActiveDirectoryMigration(self):
        """Test ActiveDirectoryMigration"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Akeyless API

    The purpose of this application is to provide access to Akeyless API.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: support@akeyless.io
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from akeyless.configuration import Configuration


class ConfigChange(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'config_hash': 'ConfigHash',
        'last_change': 'LastConfigChange',
        'last_status': 'LastStatusInfo',
        'required_activity': 'RequiredActivity',
        'update_stamp': 'int'
    }

    attribute_map = {
        'config_hash': 'config_hash',
        'last_change': 'last_change',
        'last_status': 'last_status',
        'required_activity': 'required_activity',
        'update_stamp': 'update_stamp'
    }

    def __init__(self, config_hash=None, last_change=None, last_status=None, required_activity=None, update_stamp=None, local_vars_configuration=None):  # noqa: E501
        """ConfigChange - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._config_hash = None
        self._last_change = None
        self._last_status = None
        self._required_activity = None
        self._update_stamp = None
        self.discriminator = None

        if config_hash is not None:
            self.config_hash = config_hash
        if last_change is not None:
            self.last_change = last_change
        if last_status is not None:
            self.last_status = last_status
        if required_activity is not None:
            self.required_activity = required_activity
        if update_stamp is not None:
            self.update_stamp = update_stamp

    @property
    def config_hash(self):
        """Gets the config_hash of this ConfigChange.  # noqa: E501


        :return: The config_hash of this ConfigChange.  # noqa: E501
        :rtype: ConfigHash
        """
        return self._config_hash

    @config_hash.setter
    def config_hash(self, config_hash):
        """Sets the config_hash of this ConfigChange.


        :param config_hash: The config_hash of this ConfigChange.  # noqa: E501
        :type: ConfigHash
        """

        self._config_hash = config_hash

    @property
    def last_change(self):
        """Gets the last_change of this ConfigChange.  # noqa: E501


        :return: The last_change of this ConfigChange.  # noqa: E501
        :rtype: LastConfigChange
        """
        return self._last_change

    @last_change.setter
    def last_change(self, last_change):
        """Sets the last_change of this ConfigChange.


        :param last_change: The last_change of this ConfigChange.  # noqa: E501
        :type: LastConfigChange
        """

        self._last_change = last_change

    @property
    def last_status(self):
        """Gets the last_status of this ConfigChange.  # noqa: E501


        :return: The last_status of this ConfigChange.  # noqa: E501
        :rtype: LastStatusInfo
        """
        return self._last_status

    @last_status.setter
    def last_status(self, last_status):
        """Sets the last_status of this ConfigChange.


        :param last_status: The last_status of this ConfigChange.  # noqa: E501
        :type: LastStatusInfo
        """

        self._last_status = last_status

    @property
    def required_activity(self):
        """Gets the required_activity of this ConfigChange.  # noqa: E501


        :return: The required_activity of this ConfigChange.  # noqa: E501
        :rtype: RequiredActivity
        """
        return self._required_activity

    @required_activity.setter
    def required_activity(self, required_activity):
        """Sets the required_activity of this ConfigChange.


        :param required_activity: The required_activity of this ConfigChange.  # noqa: E501
        :type: RequiredActivity
        """

        self._required_activity = required_activity

    @property
    def update_stamp(self):
        """Gets the update_stamp of this ConfigChange.  # noqa: E501


        :return: The update_stamp of this ConfigChange.  # noqa: E501
        :rtype: int
        """
        return self._update_stamp

    @update_stamp.setter
    def update_stamp(self, update_stamp):
        """Sets the update_stamp of this ConfigChange.


        :param update_stamp: The update_stamp of this ConfigChange.  # noqa: E501
        :type: int
        """

        self._update_stamp = update_stamp

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigChange):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConfigChange):
            return True

        return self.to_dict() != other.to_dict()
